/***************************************************************************
 *   Copyright 2008 by Jaroslav Reznik <rezzabuh@gmail.com> *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "atips.h"
#include <QPainter>
#include <QSizeF>
#include <QMessageBox>

#include <plasma/svg.h>
#include <plasma/theme.h>
#include <plasma/phase.h>
#include <Plasma/DataEngine>

using namespace Plasma; 

atips::atips(QObject *parent, const QVariantList &args)
    : Plasma::Applet(parent, args),
    m_size(50, 60),
    m_powerstate(0),
    m_atipslogo_svg("widgets/atipslogo", this),
    m_atipsonbtn_svg("widgets/atipsonbtn", this),
    m_atipsoffbtn_svg("widgets/atipsoffbtn", this)
{
	// draw standard background
	setDrawStandardBackground(true);

	setContentSize(50, 60);

	m_atipslogo_svg.setContentType(Plasma::Svg::SingleImage);
	m_atipsonbtn_svg.setContentType(Plasma::Svg::SingleImage);
	m_atipsoffbtn_svg.setContentType(Plasma::Svg::SingleImage);
}
 
atips::~atips()
{
	if (failedToLaunch()) 
	{
	} 
	else 
	{
	}
}

void atips::init()
{
	if (!dataEngine("atips")->query("PowerSave")["supported"].toBool())
	{
		setFailedToLaunch(true, "No ATI PowerSave support!");
		return;
	}

	connectToEngine();
}

void atips::connectToEngine()
{
	Plasma::DataEngine* atipsEngine = dataEngine("atips");
	
	atipsEngine->connectSource("Current", this, 350);
}

void atips::dataUpdated(const QString& source, const Plasma::DataEngine::Data &data)
{
	Q_UNUSED(source);

	m_powerstate = data["state"].toInt();

	update();
}

void atips::paintInterface(QPainter *p, const QStyleOptionGraphicsItem *option, const QRect &contentsRect)
{
	Q_UNUSED(option)

	p->setRenderHint(QPainter::SmoothPixmapTransform);
	p->setRenderHint(QPainter::Antialiasing);

	// render ATI logo
	m_atipslogo_svg.resize((int)contentsRect.width(), (int)contentsRect.width());
	m_atipslogo_svg.paint(p, (int)contentsRect.left(), (int)contentsRect.top());

	// render buttons
	int btnWidth = (int)contentsRect.width() / 3;
	int btnHeight = (int)contentsRect.height() * 0.10f;
	int btnTop = (int)contentsRect.width() * 1.05f;
	
	m_atipsonbtn_svg.resize(btnWidth, btnHeight);
	m_atipsoffbtn_svg.resize(btnWidth, btnHeight);

	// off buttons
	for (int i = 2; i >= m_powerstate; i--)
	{
		m_atipsoffbtn_svg.paint(p, (int)contentsRect.left() + i * btnWidth, btnTop );	
	}

	// on buttons
	for (int i = 0; i < m_powerstate; i++)
	{
		m_atipsonbtn_svg.paint(p, (int)contentsRect.left() + i * btnWidth, btnTop );	
	}
}

void atips::constraintsUpdated(Plasma::Constraints constraints)
{
	Q_UNUSED(constraints)

	updateGeometry();
}

Qt::Orientations atips::expandingDirections() const
{
	return Qt::Vertical;
}

QSizeF atips::contentSizeHint() const
{
	QSizeF sizeHint = contentSize();

	switch (formFactor()) 
	{
		case Plasma::Vertical:
			sizeHint.setHeight((int)sizeHint.width() * 0.8f);
			break;
		case Plasma::Horizontal:
			sizeHint.setWidth((int)sizeHint.height() * 0.8f);
			break;
		default:
			break;
	}

	return sizeHint;
}

#include "atips.moc"
